@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -103,7 +103,7 @@ FileAllocationIteratorHandle AbstractSingleDiskAdaptor::fileAllocationIterator()
 #endif // HAVE_POSIX_FALLOCATE
     {
       SingleFileAllocationIteratorHandle h
-	(new SingleFileAllocationIterator(this, size(), totalLength));
+        (new SingleFileAllocationIterator(this, size(), totalLength));
       h->init();
       return h;
     }
@@ -143,19 +143,9 @@ void AbstractSingleDiskAdaptor::setDiskWriter(const DiskWriterHandle& diskWriter
   this->diskWriter = diskWriter;
 }
 
-DiskWriterHandle AbstractSingleDiskAdaptor::getDiskWriter() const
-{
-  return diskWriter;
-}
-
 void AbstractSingleDiskAdaptor::setTotalLength(const uint64_t& totalLength)
 {
   this->totalLength = totalLength;
 }
 
-uint64_t AbstractSingleDiskAdaptor::getTotalLength() const
-{
-  return totalLength;
-}
-
 } // namespace aria2
