@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -66,11 +66,14 @@ BtBitfieldMessage::create(const unsigned char* data, size_t dataLength)
   bittorrent::assertPayloadLengthGreater(1,dataLength, NAME);
   bittorrent::assertID(ID, data, NAME);
   BtBitfieldMessageHandle message(new BtBitfieldMessage());
-  message->setBitfield((unsigned char*)data+1, dataLength-1);
+  message->setBitfield(data+1, dataLength-1);
   return message;
 }
 
 void BtBitfieldMessage::doReceivedAction() {
+  if(_metadataGetMode) {
+    return;
+  }
   pieceStorage->updatePieceStats(bitfield, bitfieldLength, peer->getBitfield());
   peer->setBitfield(bitfield, bitfieldLength);
   if(peer->isSeeder() && pieceStorage->downloadFinished()) {
