@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -39,11 +39,11 @@
 
 #include "ExtensionMessage.h"
 #include "ExtensionMessageFactory.h"
-#include "PeerMessageUtil.h"
+#include "bittorrent_helper.h"
 #include "Peer.h"
 #include "DlAbortEx.h"
 #include "message.h"
-#include "Util.h"
+#include "util.h"
 #include "StringFormat.h"
 #include "a2functional.h"
 
@@ -73,10 +73,10 @@ const unsigned char* BtExtendedMessage::getMessage() {
      * extpayload --- extpayload, nbytes
      * total: 6+extpayload.length bytes
      */
-    std::string payload = _extensionMessage->getBencodedData();
+    std::string payload = _extensionMessage->getPayload();
     _msgLength = 6+payload.size();
     _msg = new unsigned char[_msgLength];
-    PeerMessageUtil::createPeerMessageString(_msg, _msgLength, 2+payload.size(), ID);
+    bittorrent::createPeerMessageString(_msg, _msgLength, 2+payload.size(), ID);
     *(_msg+5) = _extensionMessage->getExtensionMessageID();
     memcpy(_msg+6, payload.c_str(), payload.size());
   }
@@ -99,14 +99,14 @@ std::string BtExtendedMessage::toString() const {
 
 BtExtendedMessageHandle
 BtExtendedMessage::create(const SharedHandle<ExtensionMessageFactory>& factory,
-			  const PeerHandle& peer,
-			  const unsigned char* data, size_t dataLength)
+                          const PeerHandle& peer,
+                          const unsigned char* data, size_t dataLength)
 {
-  PeerMessageUtil::assertPayloadLengthGreater(1, dataLength, NAME);
-  PeerMessageUtil::assertID(ID, data, NAME);
+  bittorrent::assertPayloadLengthGreater(1, dataLength, NAME);
+  bittorrent::assertID(ID, data, NAME);
   assert(!factory.isNull());
   ExtensionMessageHandle extmsg = factory->createMessage(data+1,
-							 dataLength-1);
+                                                         dataLength-1);
   BtExtendedMessageHandle message(new BtExtendedMessage(extmsg));
   return message;
 }
