@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -54,7 +54,7 @@ private:
   size_t _msgLength;
 public:
   BtExtendedMessage(const SharedHandle<ExtensionMessage>& extensionMessage =
-		    SharedHandle<ExtensionMessage>());
+                    SharedHandle<ExtensionMessage>());
 
   virtual ~BtExtendedMessage();
 
@@ -63,10 +63,10 @@ public:
   static const std::string NAME;
 
   static BtExtendedMessageHandle create
-    (const SharedHandle<ExtensionMessageFactory>& factory,
-     const SharedHandle<Peer>& peer,
-     const unsigned char* data,
-     size_t dataLength);
+  (const SharedHandle<ExtensionMessageFactory>& factory,
+   const SharedHandle<Peer>& peer,
+   const unsigned char* data,
+   size_t dataLength);
 
   virtual void doReceivedAction();
 
@@ -78,7 +78,11 @@ public:
 
   virtual std::string toString() const;
 
-  SharedHandle<ExtensionMessage> getExtensionMessage() const;
+  const SharedHandle<ExtensionMessage>& getExtensionMessage() const
+  {
+    return _extensionMessage;
+  }
+
 };
 
 } // namespace aria2
