@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -41,6 +41,7 @@ namespace aria2 {
 
 class Piece;
 class BtPieceMessage;
+class DownloadContext;
 
 typedef SharedHandle<BtPieceMessage> BtPieceMessageHandle;
 
@@ -51,6 +52,7 @@ private:
   uint32_t blockLength;
   unsigned char* block;
   unsigned char* msgHeader;
+  SharedHandle<DownloadContext> _downloadContext;
 
   static size_t MESSAGE_HEADER_LENGTH;
 
@@ -100,6 +102,8 @@ public:
 
   void setBlockLength(size_t blockLength) { this->blockLength = blockLength; }
 
+  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext);
+
   static BtPieceMessageHandle create(const unsigned char* data, size_t dataLength);
 
   virtual void doReceivedAction();
