@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -41,19 +41,22 @@
 #include "File.h"
 #include "PieceStorage.h"
 #include "DiskAdaptor.h"
-#include "Util.h"
+#include "util.h"
 #include "ContentTypeRequestGroupCriteria.h"
 #include "Exception.h"
 #include "DownloadContext.h"
-#include "bittorrent_helper.h"
+#include "download_helper.h"
 
 namespace aria2 {
 
 BtPostDownloadHandler::BtPostDownloadHandler()
 {
   SharedHandle<RequestGroupCriteria> cri
-    (new ContentTypeRequestGroupCriteria(DownloadHandlerConstants::getBtContentTypes(),
-					 DownloadHandlerConstants::getBtExtensions()));
+    (new ContentTypeRequestGroupCriteria
+     (DownloadHandlerConstants::getBtContentTypes().begin(),
+      DownloadHandlerConstants::getBtContentTypes().end(),
+      DownloadHandlerConstants::getBtExtensions().begin(),
+      DownloadHandlerConstants::getBtExtensions().end()));
   setCriteria(cri);
 }
 
@@ -63,28 +66,23 @@ void BtPostDownloadHandler::getNextRequestGroups
 (std::deque<SharedHandle<RequestGroup> >& groups,
  RequestGroup* requestGroup)
 {
-  const SharedHandle<Option>& op = requestGroup->getOption();
   _logger->debug("Generating RequestGroups for Torrent file %s",
-		 requestGroup->getFirstFilePath().c_str());
-  RequestGroupHandle rg(new RequestGroup(op));
-
+                 requestGroup->getFirstFilePath().c_str());
   std::string content;
   try {
     requestGroup->getPieceStorage()->getDiskAdaptor()->openExistingFile();
-    content = Util::toString(requestGroup->getPieceStorage()->getDiskAdaptor());
+    content = util::toString(requestGroup->getPieceStorage()->getDiskAdaptor());
     requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();    
   } catch(Exception& e) {
     requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();
     throw;
   }
-  SharedHandle<DownloadContext> context(new DownloadContext());
-  context->setDir(requestGroup->getDownloadContext()->getDir());
-  bittorrent::loadFromMemory(content, context,
-			     File(requestGroup->getFirstFilePath()).getBasename());
-  rg->setDownloadContext(context);
-  context->setOwnerRequestGroup(rg.get());
-  
-  groups.push_back(rg);
+  std::deque<SharedHandle<RequestGroup> > newRgs;
+  createRequestGroupForBitTorrent(newRgs, requestGroup->getOption(),
+                                  std::deque<std::string>(),
+                                  content);
+  requestGroup->followedBy(newRgs.begin(), newRgs.end());
+  groups.insert(groups.end(), newRgs.begin(), newRgs.end());
 }
 
 } // namespace aria2
