@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -72,7 +72,8 @@
 namespace aria2 {
 
 static void printProgress
-(std::ostream& o, const SharedHandle<RequestGroup>& rg, const DownloadEngine* e)
+(std::ostream& o, const SharedHandle<RequestGroup>& rg, const DownloadEngine* e,
+ const SizeFormatter& sizeFormatter)
 {
   TransferStat stat = rg->calculateStat();
   unsigned int eta = 0;
@@ -85,11 +86,13 @@ static void printProgress
 
 #ifdef ENABLE_BITTORRENT
   if(rg->getDownloadContext()->hasAttribute(bittorrent::BITTORRENT) &&
+     rg->getDownloadContext()->getAttribute(bittorrent::BITTORRENT)
+     .containsKey(bittorrent::METADATA) &&
      rg->downloadFinished()) {
     o << "SEEDING" << "(" << "ratio:";
     if(rg->getCompletedLength() > 0) {
       o << std::fixed << std::setprecision(1)
-	<< ((stat.getAllTimeUploadLength()*10)/rg->getCompletedLength())/10.0;
+        << ((stat.getAllTimeUploadLength()*10)/rg->getCompletedLength())/10.0;
     } else {
       o << "--";
     }
@@ -98,26 +101,24 @@ static void printProgress
 #endif // ENABLE_BITTORRENT
     {
       o << "SIZE:"
-	<< util::abbrevSize(rg->getCompletedLength())
-	<< "B"
-	<< "/"
-	<< util::abbrevSize(rg->getTotalLength())
-	<< "B";
+        << sizeFormatter(rg->getCompletedLength())
+        << "B"
+        << "/"
+        << sizeFormatter(rg->getTotalLength())
+        << "B";
       if(rg->getTotalLength() > 0) {
-	o << "("
-	  << 100*rg->getCompletedLength()/rg->getTotalLength()
-	  << "%)";
+        o << "("
+          << 100*rg->getCompletedLength()/rg->getTotalLength()
+          << "%)";
       }
     }
   o << " "
     << "CN:"
     << rg->getNumConnection();
 #ifdef ENABLE_BITTORRENT
-  if(rg->getDownloadContext()->hasAttribute(bittorrent::BITTORRENT)) {
-    const BDE& torrentAttrs =
-      rg->getDownloadContext()->getAttribute(bittorrent::BITTORRENT);
-    SharedHandle<PeerStorage> ps =
-      e->getBtRegistry()->get(torrentAttrs[bittorrent::INFO_HASH].s())._peerStorage;
+  SharedHandle<PeerStorage> ps =
+    e->getBtRegistry()->get(rg->getGID())._peerStorage;
+  if(!ps.isNull()) {
     std::deque<SharedHandle<Peer> > peers;
     ps->getActivePeers(peers);
     o << " " << "SEED:"
@@ -128,13 +129,13 @@ static void printProgress
   if(!rg->downloadFinished()) {
     o << " "
       << "SPD:"
-      << util::abbrevSize(stat.getDownloadSpeed()) << "Bs";
+      << sizeFormatter(stat.getDownloadSpeed()) << "Bs";
   }
   if(stat.getSessionUploadLength() > 0) {
     o << " "
       << "UP:"
-      << util::abbrevSize(stat.getUploadSpeed()) << "Bs"
-      << "(" << util::abbrevSize(stat.getAllTimeUploadLength()) << "B)";
+      << sizeFormatter(stat.getUploadSpeed()) << "Bs"
+      << "(" << sizeFormatter(stat.getAllTimeUploadLength()) << "B)";
   }
   if(eta > 0) {
     o << " "
@@ -149,27 +150,32 @@ class PrintSummary
 private:
   size_t _cols;
   const DownloadEngine* _e;
+  const SizeFormatter& _sizeFormatter;
 public:
-  PrintSummary(size_t cols, const DownloadEngine* e):_cols(cols), _e(e) {}
+  PrintSummary
+  (size_t cols, const DownloadEngine* e,
+   const SizeFormatter& sizeFormatter):
+    _cols(cols), _e(e), _sizeFormatter(sizeFormatter) {}
 
   void operator()(const SharedHandle<RequestGroup>& rg)
   {
     const char SEP_CHAR = '-';
-    printProgress(std::cout, rg, _e);
+    printProgress(std::cout, rg, _e, _sizeFormatter);
     const std::vector<SharedHandle<FileEntry> >& fileEntries =
       rg->getDownloadContext()->getFileEntries();
     std::cout << "\n"
-	      << "FILE: ";
+              << "FILE: ";
     writeFilePath(fileEntries.begin(), fileEntries.end(),
-		  std::cout, rg->inMemoryDownload());
+                  std::cout, rg->inMemoryDownload());
     std::cout << "\n"
-	      << std::setfill(SEP_CHAR) << std::setw(_cols) << SEP_CHAR << "\n";
+              << std::setfill(SEP_CHAR) << std::setw(_cols) << SEP_CHAR << "\n";
   }
 };
 
 static void printProgressSummary
 (const std::deque<SharedHandle<RequestGroup> >& groups, size_t cols,
- const DownloadEngine* e)
+ const DownloadEngine* e,
+ const SizeFormatter& sizeFormatter)
 {
   const char SEP_CHAR = '=';
   time_t now;
@@ -183,19 +189,26 @@ static void printProgressSummary
        asctime_r(staticNowtmPtr, buf) != 0) {
       char* lfptr = strchr(buf, '\n');
       if(lfptr) {
-	*lfptr = '\0';
+        *lfptr = '\0';
       }
       std::cout << " as of " << buf;
     }
   }
   std::cout << " *** " << "\n"
-	    << std::setfill(SEP_CHAR) << std::setw(cols) << SEP_CHAR << "\n";
-  std::for_each(groups.begin(), groups.end(), PrintSummary(cols, e));
+            << std::setfill(SEP_CHAR) << std::setw(cols) << SEP_CHAR << "\n";
+  std::for_each(groups.begin(), groups.end(),
+                PrintSummary(cols, e, sizeFormatter));
 }
 
-ConsoleStatCalc::ConsoleStatCalc(time_t summaryInterval):
+ConsoleStatCalc::ConsoleStatCalc(time_t summaryInterval, bool humanReadable):
   _summaryInterval(summaryInterval)
-{}
+{
+  if(humanReadable) {
+    _sizeFormatter.reset(new AbbrevSizeFormatter());
+  } else {
+    _sizeFormatter.reset(new PlainSizeFormatter());
+  }
+}
 
 void
 ConsoleStatCalc::calculateStat(const DownloadEngine* e)
@@ -204,7 +217,7 @@ ConsoleStatCalc::calculateStat(const DownloadEngine* e)
     return;
   }
   _cp.reset();
-
+  const SizeFormatter& sizeFormatter = *_sizeFormatter.get();
   bool isTTY = isatty(STDOUT_FILENO) == 1;
   unsigned short int cols = 80;
 #ifdef __MINGW32__
@@ -218,8 +231,8 @@ ConsoleStatCalc::calculateStat(const DownloadEngine* e)
       cols = size.ws_col;
 #ifdef __MINGW32__
       if(cols > 0) {
-	// Windows terminal cannot handle at the end of line properly.
-	--cols;
+        // Windows terminal cannot handle at the end of line properly.
+        --cols;
       }
 #endif // __MINGW32__
     }
@@ -231,18 +244,19 @@ ConsoleStatCalc::calculateStat(const DownloadEngine* e)
     if((_summaryInterval > 0) &&
        _lastSummaryNotified.elapsed(_summaryInterval)) {
       _lastSummaryNotified.reset();
-      printProgressSummary(e->_requestGroupMan->getRequestGroups(), cols, e);
+      printProgressSummary(e->_requestGroupMan->getRequestGroups(), cols, e,
+                           sizeFormatter);
       std::cout << "\n";
     }
 
     RequestGroupHandle firstRequestGroup = e->_requestGroupMan->getRequestGroup(0);
 
-    printProgress(o, firstRequestGroup, e);
+    printProgress(o, firstRequestGroup, e, sizeFormatter);
 
     if(e->_requestGroupMan->countRequestGroup() > 1) {
       o << "("
-	<< e->_requestGroupMan->countRequestGroup()-1
-	<< "more...)";
+        << e->_requestGroupMan->countRequestGroup()-1
+        << "more...)";
     }
   }
 
@@ -251,32 +265,32 @@ ConsoleStatCalc::calculateStat(const DownloadEngine* e)
     TransferStat stat = e->_requestGroupMan->calculateStat();
     o << " "
       << "[TOTAL SPD:"
-      << util::abbrevSize(stat.getDownloadSpeed()) << "Bs" << "]";
+      << sizeFormatter(stat.getDownloadSpeed()) << "Bs" << "]";
   }
 
   {
     SharedHandle<FileAllocationEntry> entry=e->_fileAllocationMan->getPickedEntry();
     if(!entry.isNull()) {
       o << " "
-	<< "[FileAlloc:"
-	<< "#" << entry->getRequestGroup()->getGID() << " "
-	<< util::abbrevSize(entry->getCurrentLength())
-	<< "B"
-	<< "/"
-	<< util::abbrevSize(entry->getTotalLength())
-	<< "B"
-	<< "(";
+        << "[FileAlloc:"
+        << "#" << entry->getRequestGroup()->getGID() << " "
+        << sizeFormatter(entry->getCurrentLength())
+        << "B"
+        << "/"
+        << sizeFormatter(entry->getTotalLength())
+        << "B"
+        << "(";
       if(entry->getTotalLength() > 0) {
-	o << 100*entry->getCurrentLength()/entry->getTotalLength();
+        o << 100*entry->getCurrentLength()/entry->getTotalLength();
       } else {
-	o << "--";
+        o << "--";
       }
       o << "%)"
-	<< "]";
+        << "]";
       if(e->_fileAllocationMan->hasNext()) {
-	o << "("
-	  << e->_fileAllocationMan->countEntryInQueue()
-	  << "waiting...)";
+        o << "("
+          << e->_fileAllocationMan->countEntryInQueue()
+          << "waiting...)";
       }
     }
   }
@@ -285,21 +299,21 @@ ConsoleStatCalc::calculateStat(const DownloadEngine* e)
     CheckIntegrityEntryHandle entry = e->_checkIntegrityMan->getPickedEntry();
     if(!entry.isNull()) {
       o << " "
-	<< "[Checksum:"
-	<< "#" << entry->getRequestGroup()->getGID() << " "
-	<< util::abbrevSize(entry->getCurrentLength())
-	<< "B"
-	<< "/"
-	<< util::abbrevSize(entry->getTotalLength())
-	<< "B"
-	<< "("
-	<< 100*entry->getCurrentLength()/entry->getTotalLength()
-	<< "%)"
-	<< "]";
+        << "[Checksum:"
+        << "#" << entry->getRequestGroup()->getGID() << " "
+        << sizeFormatter(entry->getCurrentLength())
+        << "B"
+        << "/"
+        << sizeFormatter(entry->getTotalLength())
+        << "B"
+        << "("
+        << 100*entry->getCurrentLength()/entry->getTotalLength()
+        << "%)"
+        << "]";
       if(e->_checkIntegrityMan->hasNext()) {
-	o << "("
-	  << e->_checkIntegrityMan->countEntryInQueue()
-	  << "waiting...)";
+        o << "("
+          << e->_checkIntegrityMan->countEntryInQueue()
+          << "waiting...)";
       }
     }
   }
