@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,7 +37,7 @@
 #include <algorithm>
 #include <sstream>
 
-#include "Util.h"
+#include "util.h"
 #include "A2STR.h"
 #include "TimeA2.h"
 #include "a2functional.h"
@@ -56,24 +56,24 @@ static std::string prependDotIfNotExists(const std::string& domain)
 
 static std::string normalizeDomain(const std::string& domain)
 {
-  if(domain.empty() || Util::isNumbersAndDotsNotation(domain)) {
+  if(domain.empty() || util::isNumbersAndDotsNotation(domain)) {
     return domain;
   }
   std::string md = prependDotIfNotExists(domain);
-  // TODO use Util::split to strict verification
+  // TODO use util::split to strict verification
   std::string::size_type p = md.find_last_of(".");
   if(p == 0 || p == std::string::npos) {
     md += ".local";
   }
-  return Util::toLower(prependDotIfNotExists(md));
+  return util::toLower(prependDotIfNotExists(md));
 }
 
 Cookie::Cookie(const std::string& name,
-	       const std::string& value,
-	       time_t  expiry,
-	       const std::string& path,
-	       const std::string& domain,
-	       bool secure):
+               const std::string& value,
+               time_t  expiry,
+               const std::string& path,
+               const std::string& domain,
+               bool secure):
   _name(name),
   _value(value),
   _expiry(expiry),
@@ -82,10 +82,10 @@ Cookie::Cookie(const std::string& name,
   _secure(secure) {}
 
 Cookie::Cookie(const std::string& name,
-	       const std::string& value,
-	       const std::string& path,
-	       const std::string& domain,
-	       bool secure):
+               const std::string& value,
+               const std::string& path,
+               const std::string& domain,
+               bool secure):
   _name(name),
   _value(value),
   _expiry(0),
@@ -112,19 +112,19 @@ static bool pathInclude(const std::string& requestPath, const std::string& path)
   if(requestPath == path) {
     return true;
   }
-  if(Util::startsWith(requestPath, path)) {
+  if(util::startsWith(requestPath, path)) {
     if(*path.rbegin() != '/' && requestPath[path.size()] != '/') {
       return false;
     }
   } else if(*path.rbegin() != '/' || *requestPath.rbegin() == '/' ||
-	    !Util::startsWith(requestPath+"/", path)) {
+            !util::startsWith(requestPath+"/", path)) {
     return false;
   }
   return true;
 }
 
 static bool domainMatch(const std::string& normReqHost,
-			const std::string& domain)
+                        const std::string& domain)
 {
   // RFC2965 stated that:
   //
@@ -135,12 +135,12 @@ static bool domainMatch(const std::string& normReqHost,
   // Also original Netscape implementation behaves exactly the same.
 
   // _domain always starts ".". See Cookie::Cookie().
-  return Util::endsWith(normReqHost, domain);
+  return util::endsWith(normReqHost, domain);
 }
 
 bool Cookie::match(const std::string& requestHost,
-		   const std::string& requestPath,
-		   time_t date, bool secure) const
+                   const std::string& requestPath,
+                   time_t date, bool secure) const
 {
   std::string normReqHost = normalizeDomain(requestHost);
   if((secure || (!_secure && !secure)) &&
@@ -172,7 +172,7 @@ bool Cookie::validate(const std::string& requestHost,
     if(_domain.size() < 4 || _domain.find(".", 1) == std::string::npos) {
       return false;
     }
-    if(!Util::endsWith(normReqHost, _domain)) {
+    if(!util::endsWith(normReqHost, _domain)) {
       return false;
     }
     // From RFC2965 3.3.2 Rejecting Cookies
@@ -211,7 +211,7 @@ std::string Cookie::toNsCookieFormat() const
 {
   std::stringstream ss;
   ss << _domain << "\t";
-  if(Util::startsWith(_domain, ".")) {
+  if(util::startsWith(_domain, ".")) {
     ss << "TRUE";
   } else {
     ss << "FALSE";
