@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -42,7 +42,7 @@
 #include "DHTTaskQueue.h"
 #include "DHTTaskFactory.h"
 #include "DHTTask.h"
-#include "Util.h"
+#include "util.h"
 #include "LogFactory.h"
 #include "Logger.h"
 
@@ -77,7 +77,7 @@ bool DHTRoutingTable::addNode(const SharedHandle<DHTNode>& node, bool good)
   _logger->debug("Trying to add node:%s", node->toString().c_str());
   if(_localNode == node) {
     _logger->debug("Adding node with the same ID with localnode is not"
-		   " allowed.");
+                   " allowed.");
     return false;
   }
   BNode* bnode = BNode::findBNodeFor(_root, node->getID());
@@ -88,8 +88,8 @@ bool DHTRoutingTable::addNode(const SharedHandle<DHTNode>& node, bool good)
       return true;
     } else if(bucket->splitAllowed()) {
       _logger->debug("Splitting bucket. Range:%s-%s",
-		     Util::toHex(bucket->getMinID(), DHT_ID_LENGTH).c_str(),
-		     Util::toHex(bucket->getMaxID(), DHT_ID_LENGTH).c_str());
+                     util::toHex(bucket->getMinID(), DHT_ID_LENGTH).c_str(),
+                     util::toHex(bucket->getMaxID(), DHT_ID_LENGTH).c_str());
       SharedHandle<DHTBucket> r = bucket->split();
 
       bnode->setBucket(SharedHandle<DHTBucket>());
@@ -100,15 +100,15 @@ bool DHTRoutingTable::addNode(const SharedHandle<DHTNode>& node, bool good)
       ++_numBucket;
 
       if(r->isInRange(node)) {
-	bucket = r;
-	bnode = rbnode;
+        bucket = r;
+        bnode = rbnode;
       } else {
-	bnode = lbnode;
+        bnode = lbnode;
       }
     } else {
       if(good) {
-	bucket->cacheNode(node);
-	_logger->debug("Cached node=%s", node->toString().c_str());
+        bucket->cacheNode(node);
+        _logger->debug("Cached node=%s", node->toString().c_str());
       }
       return false;
     }
@@ -117,7 +117,7 @@ bool DHTRoutingTable::addNode(const SharedHandle<DHTNode>& node, bool good)
 }
 
 void DHTRoutingTable::getClosestKNodes(std::deque<SharedHandle<DHTNode> >& nodes,
-				       const unsigned char* key) const
+                                       const unsigned char* key) const
 {
   BNode::findClosestKNodes(nodes, _root, key);
 }
@@ -129,10 +129,10 @@ size_t DHTRoutingTable::countBucket() const
 
 void DHTRoutingTable::showBuckets() const
 {/*
-  for(std::deque<SharedHandle<DHTBucket> >::const_iterator itr = _buckets.begin(); itr != _buckets.end(); ++itr) {
-    cerr << "prefix = " << (*itr)->getPrefixLength() << ", "
-	 << "nodes = " << (*itr)->countNode() << endl;
-  }
+   for(std::deque<SharedHandle<DHTBucket> >::const_iterator itr = _buckets.begin(); itr != _buckets.end(); ++itr) {
+   cerr << "prefix = " << (*itr)->getPrefixLength() << ", "
+   << "nodes = " << (*itr)->countNode() << endl;
+   }
  */
 }
 
@@ -157,10 +157,10 @@ void DHTRoutingTable::dropNode(const SharedHandle<DHTNode>& node)
   getBucketFor(node)->dropNode(node);
 }
 /*
-void DHTRoutingTable::moveBucketHead(const SharedHandle<DHTNode>& node)
-{
+  void DHTRoutingTable::moveBucketHead(const SharedHandle<DHTNode>& node)
+  {
   getBucketFor(node)->moveToHead(node);
-}
+  }
 */
 void DHTRoutingTable::moveBucketTail(const SharedHandle<DHTNode>& node)
 {
