@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -51,13 +51,12 @@
 #include "TimeA2.h"
 #include "a2time.h"
 #include "Socket.h"
-#include "Util.h"
+#include "util.h"
 #include "a2functional.h"
 #include "DlAbortEx.h"
 #include "ServerStatMan.h"
 #include "CookieStorage.h"
 #include "A2STR.h"
-#include "DNSCache.h"
 #include "AuthConfigFactory.h"
 #include "AuthConfig.h"
 #include "Request.h"
@@ -95,7 +94,11 @@ DownloadEngine::DownloadEngine(const SharedHandle<EventPoll>& eventPoll):
   _btRegistry(new BtRegistry()),
 #endif // ENABLE_BITTORRENT
   _dnsCache(new DNSCache())
-{}
+{
+  unsigned char sessionId[20];
+  util::generateRandomKey(sessionId);
+  _sessionId = std::string(&sessionId[0], & sessionId[sizeof(sessionId)]);
+}
 
 DownloadEngine::~DownloadEngine() {
   cleanQueue();
@@ -107,7 +110,7 @@ void DownloadEngine::cleanQueue() {
 }
 
 static void executeCommand(std::deque<Command*>& commands,
-			   Command::STATUS statusFilter)
+                           Command::STATUS statusFilter)
 {
   size_t max = commands.size();
   for(size_t i = 0; i < max; ++i) {
@@ -116,8 +119,8 @@ static void executeCommand(std::deque<Command*>& commands,
     if(com->statusMatch(statusFilter)) {
       com->transitStatus();
       if(com->execute()) {
-	delete com;
-	com = 0;
+        delete com;
+        com = 0;
       }
     } else {
       commands.push_back(com);
@@ -164,31 +167,31 @@ void DownloadEngine::waitData()
 }
 
 bool DownloadEngine::addSocketForReadCheck(const SocketHandle& socket,
-					   Command* command)
+                                           Command* command)
 {
   return _eventPoll->addEvents(socket->getSockfd(), command,
-			       EventPoll::EVENT_READ);
+                               EventPoll::EVENT_READ);
 }
 
 bool DownloadEngine::deleteSocketForReadCheck(const SocketHandle& socket,
-					      Command* command)
+                                              Command* command)
 {
   return _eventPoll->deleteEvents(socket->getSockfd(), command,
-				  EventPoll::EVENT_READ);
+                                  EventPoll::EVENT_READ);
 }
 
 bool DownloadEngine::addSocketForWriteCheck(const SocketHandle& socket,
-					    Command* command)
+                                            Command* command)
 {
   return _eventPoll->addEvents(socket->getSockfd(), command,
-			       EventPoll::EVENT_WRITE);
+                               EventPoll::EVENT_WRITE);
 }
 
 bool DownloadEngine::deleteSocketForWriteCheck(const SocketHandle& socket,
-					       Command* command)
+                                               Command* command)
 {
   return _eventPoll->deleteEvents(socket->getSockfd(), command,
-				  EventPoll::EVENT_WRITE);
+                                  EventPoll::EVENT_WRITE);
 }
 
 void DownloadEngine::calculateStatistics()
@@ -229,13 +232,6 @@ void DownloadEngine::requestHalt()
   _requestGroupMan->halt();
 }
 
-void DownloadEngine::fillCommand()
-{
-  std::deque<Command*> commands;
-  _requestGroupMan->getInitialCommands(commands, this);
-  addCommand(commands);
-}
-
 void DownloadEngine::setStatCalc(const StatCalcHandle& statCalc)
 {
   _statCalc = statCalc;
@@ -271,10 +267,10 @@ void DownloadEngine::addRoutineCommand(Command* command)
 }
 
 void DownloadEngine::poolSocket(const std::string& ipaddr,
-				uint16_t port,
-				const SocketPoolEntry& entry)
+                                uint16_t port,
+                                const SocketPoolEntry& entry)
 {
-  std::string addr = strconcat(ipaddr, ":", Util::uitos(port));
+  std::string addr = strconcat(ipaddr, ":", util::uitos(port));
   logger->info("Pool socket for %s", addr.c_str());
   std::multimap<std::string, SocketPoolEntry>::value_type p(addr, entry);
   _socketPool.insert(p);
@@ -284,9 +280,9 @@ void DownloadEngine::poolSocket(const std::string& ipaddr,
     logger->debug("Scaning SocketPool and erasing timed out entry.");
     _lastSocketPoolScan.reset();
     for(std::multimap<std::string, SocketPoolEntry>::iterator i =
-	  _socketPool.begin(); i != _socketPool.end(); ++i) {
+          _socketPool.begin(); i != _socketPool.end(); ++i) {
       if(!(*i).second.isTimeout()) {
-	newPool.insert(*i);
+        newPool.insert(*i);
       }
     }
     logger->debug
@@ -318,9 +314,9 @@ void DownloadEngine::poolSocket
 }
 
 void DownloadEngine::poolSocket(const SharedHandle<Request>& request,
-				bool proxyDefined,
-				const SharedHandle<SocketCore>& socket,
-				time_t timeout)
+                                bool proxyDefined,
+                                const SharedHandle<SocketCore>& socket,
+                                time_t timeout)
 {
   if(proxyDefined) {
     // If proxy is defined, then pool socket with its hostname.
@@ -336,7 +332,7 @@ void DownloadEngine::poolSocket
 (const SharedHandle<Request>& request,
  bool proxyDefined,
  const SharedHandle<SocketCore>& socket,
- const std::map<std::string, std::string>& options,				
+ const std::map<std::string, std::string>& options,                             
  time_t timeout)
 {
   if(proxyDefined) {
@@ -353,7 +349,7 @@ std::multimap<std::string, DownloadEngine::SocketPoolEntry>::iterator
 DownloadEngine::findSocketPoolEntry(const std::string& ipaddr, uint16_t port)
 {
   std::string addr = ipaddr;
-  strappend(addr, ":", Util::uitos(port));
+  strappend(addr, ":", util::uitos(port));
   std::pair<std::multimap<std::string, SocketPoolEntry>::iterator,
     std::multimap<std::string, SocketPoolEntry>::iterator> range =
     _socketPool.equal_range(addr);
@@ -383,7 +379,7 @@ DownloadEngine::popPooledSocket(const std::string& ipaddr, uint16_t port)
 
 SharedHandle<SocketCore>
 DownloadEngine::popPooledSocket(std::map<std::string, std::string>& options,
-				const std::string& ipaddr, uint16_t port)
+                                const std::string& ipaddr, uint16_t port)
 {
   SharedHandle<SocketCore> s;
   std::multimap<std::string, SocketPoolEntry>::iterator i =
