@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -51,6 +51,7 @@
 #include "CUIDCounter.h"
 #include "FileAllocationMan.h"
 #include "CheckIntegrityMan.h"
+#include "DNSCache.h"
 
 namespace aria2 {
 
@@ -60,7 +61,6 @@ class RequestGroupMan;
 class StatCalc;
 class SocketCore;
 class CookieStorage;
-class DNSCache;
 class AuthConfigFactory;
 class Request;
 class EventPoll;
@@ -73,6 +73,8 @@ class DownloadEngine {
 private:
   void waitData();
 
+  std::string _sessionId;
+
   SharedHandle<EventPoll> _eventPoll;
 
   Logger* logger;
@@ -92,8 +94,8 @@ private:
     Time _registeredTime;
   public:
     SocketPoolEntry(const SharedHandle<SocketCore>& socket,
-		    const std::map<std::string, std::string>& option,
-		    time_t timeout);
+                    const std::map<std::string, std::string>& option,
+                    time_t timeout);
 
     ~SocketPoolEntry();
 
@@ -145,8 +147,8 @@ private:
   void afterEachIteration();
   
   void poolSocket(const std::string& ipaddr,
-		  uint16_t port,
-		  const SocketPoolEntry& entry);
+                  uint16_t port,
+                  const SocketPoolEntry& entry);
 
   std::multimap<std::string, SocketPoolEntry>::iterator
   findSocketPoolEntry(const std::string& ipaddr, uint16_t port);
@@ -155,7 +157,7 @@ public:
   SharedHandle<RequestGroupMan> _requestGroupMan;
   SharedHandle<FileAllocationMan> _fileAllocationMan;
   SharedHandle<CheckIntegrityMan> _checkIntegrityMan;
-  const Option* option;
+  Option* option;
   
   DownloadEngine(const SharedHandle<EventPoll>& eventPoll);
 
@@ -166,26 +168,24 @@ public:
   void cleanQueue();
 
   bool addSocketForReadCheck(const SharedHandle<SocketCore>& socket,
-			     Command* command);
+                             Command* command);
   bool deleteSocketForReadCheck(const SharedHandle<SocketCore>& socket,
-				Command* command);
+                                Command* command);
   bool addSocketForWriteCheck(const SharedHandle<SocketCore>& socket,
-			      Command* command);
+                              Command* command);
   bool deleteSocketForWriteCheck(const SharedHandle<SocketCore>& socket,
-				 Command* command);
+                                 Command* command);
 
 #ifdef ENABLE_ASYNC_DNS
 
   bool addNameResolverCheck(const SharedHandle<AsyncNameResolver>& resolver,
-			    Command* command);
+                            Command* command);
   bool deleteNameResolverCheck(const SharedHandle<AsyncNameResolver>& resolver,
-			       Command* command);
+                               Command* command);
 #endif // ENABLE_ASYNC_DNS
 
   void addCommand(const std::deque<Command*>& commands);
 
-  void fillCommand();
-
   void setStatCalc(const SharedHandle<StatCalc>& statCalc);
 
   bool isHaltRequested() const
@@ -200,27 +200,27 @@ public:
   void addRoutineCommand(Command* command);
 
   void poolSocket(const std::string& ipaddr, uint16_t port,
-		  const SharedHandle<SocketCore>& sock,
-		  const std::map<std::string, std::string>& options,
-		  time_t timeout = 15);
+                  const SharedHandle<SocketCore>& sock,
+                  const std::map<std::string, std::string>& options,
+                  time_t timeout = 15);
 
   void poolSocket(const std::string& ipaddr, uint16_t port,
-		  const SharedHandle<SocketCore>& sock,
-		  time_t timeout = 15);
+                  const SharedHandle<SocketCore>& sock,
+                  time_t timeout = 15);
   
   void poolSocket(const SharedHandle<Request>& request,
-		  bool proxyDefined,
-		  const SharedHandle<SocketCore>& socket,
-		  const std::map<std::string, std::string>& options,
-		  time_t timeout = 15);
+                  bool proxyDefined,
+                  const SharedHandle<SocketCore>& socket,
+                  const std::map<std::string, std::string>& options,
+                  time_t timeout = 15);
     
   void poolSocket(const SharedHandle<Request>& request,
-		  bool proxyDefined,
-		  const SharedHandle<SocketCore>& socket,
-		  time_t timeout = 15);
+                  bool proxyDefined,
+                  const SharedHandle<SocketCore>& socket,
+                  time_t timeout = 15);
 
   SharedHandle<SocketCore> popPooledSocket(const std::string& ipaddr,
-					   uint16_t port);
+                                           uint16_t port);
 
   SharedHandle<SocketCore> popPooledSocket
   (std::map<std::string, std::string>& options,
@@ -253,6 +253,13 @@ public:
   const std::string& findCachedIPAddress
   (const std::string& hostname, uint16_t port) const;
 
+  template<typename OutputIterator>
+  void findAllCachedIPAddresses
+  (OutputIterator out, const std::string& hostname, uint16_t port) const
+  {
+    _dnsCache->findAll(out, hostname, port);
+  }
+
   void cacheIPAddress
   (const std::string& hostname, const std::string& ipaddr, uint16_t port);
 
@@ -269,6 +276,11 @@ public:
   }
 
   void setRefreshInterval(time_t interval);
+
+  const std::string getSessionId() const
+  {
+    return _sessionId;
+  }
 };
 
 typedef SharedHandle<DownloadEngine> DownloadEngineHandle;
