@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -109,6 +109,11 @@ public:
   bool utime(const Time& actime, const Time& modtime) const;
 
   Time getModifiedTime();
+
+  // Returns the current working directory.  If the current working
+  // directory cannot be retrieved or its length is larger than 2048,
+  // returns ".".
+  static std::string getCurrentDir();
 };
 
 } // namespace aria2
