@@ -2,7 +2,7 @@
 /*
  * aria2 - The high speed download utility
  *
- * Copyright (C) 2006 Tatsuhiro Tsujikawa
+ * Copyright (C) 2009 Tatsuhiro Tsujikawa
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -41,6 +41,10 @@
 #include "message.h"
 #include "StringFormat.h"
 #include "bencode.h"
+#include "DownloadContext.h"
+#include "bittorrent_helper.h"
+#include "RequestGroup.h"
+#include "PieceStorage.h"
 
 namespace aria2 {
 
@@ -48,11 +52,12 @@ const std::string HandshakeExtensionMessage::EXTENSION_NAME = "handshake";
 
 HandshakeExtensionMessage::HandshakeExtensionMessage():
   _tcpPort(0),
+  _metadataSize(0),
   _logger(LogFactory::getInstance()) {}
 
 HandshakeExtensionMessage::~HandshakeExtensionMessage() {}
 
-std::string HandshakeExtensionMessage::getBencodedData()
+std::string HandshakeExtensionMessage::getPayload()
 {
   BDE dict = BDE::dict();
   if(!_clientVersion.empty()) {
@@ -68,6 +73,9 @@ std::string HandshakeExtensionMessage::getBencodedData()
     extDict[vt.first] = vt.second;
   }
   dict["m"] = extDict;
+  if(_metadataSize) {
+    dict["metadata_size"] = _metadataSize;
+  }
   return bencode::encode(dict);
 }
 
@@ -80,6 +88,9 @@ std::string HandshakeExtensionMessage::toString() const
   if(_tcpPort > 0) {
     strappend(s, ", tcpPort=", util::uitos(_tcpPort));
   }
+  if(_metadataSize) {
+    strappend(s, ", metadataSize=", util::uitos(_metadataSize));
+  }
   for(std::map<std::string, uint8_t>::const_iterator itr = _extensions.begin();
       itr != _extensions.end(); ++itr) {
     const std::map<std::string, uint8_t>::value_type& vt = *itr;
@@ -99,6 +110,33 @@ void HandshakeExtensionMessage::doReceivedAction()
     const std::map<std::string, uint8_t>::value_type& vt = *itr;
     _peer->setExtension(vt.first, vt.second);
   }
+  BDE& attrs = _dctx->getAttribute(bittorrent::BITTORRENT);
+  if(!attrs.containsKey(bittorrent::METADATA) &&
+     !_peer->getExtensionMessageID("ut_metadata")) {
+    // TODO In metadataGetMode, if peer don't support metadata
+    // transfer, should we drop connection? There is a possibility
+    // that peer can still tell us peers using PEX.
+    throw DL_ABORT_EX("Peer doesn't support ut_metadata extension. Goodbye.");
+  }
+  if(_metadataSize > 0) {
+    if(attrs.containsKey(bittorrent::METADATA_SIZE)) {
+      if(_metadataSize != (size_t)attrs[bittorrent::METADATA_SIZE].i()) {
+        throw DL_ABORT_EX("Wrong metadata_size. Which one is correct!?");
+      }
+    } else {
+      attrs[bittorrent::METADATA_SIZE] = _metadataSize;
+      _dctx->getFirstFileEntry()->setLength(_metadataSize);
+      _dctx->markTotalLengthIsKnown();
+      _dctx->getOwnerRequestGroup()->initPieceStorage();
+      
+      SharedHandle<PieceStorage> pieceStorage =
+        _dctx->getOwnerRequestGroup()->getPieceStorage();
+      pieceStorage->setEndGamePieceNum(0);
+    }
+  } else if(!attrs.containsKey(bittorrent::METADATA)) {
+    throw DL_ABORT_EX("Peer didn't provide metadata_size."
+                      " It seems that it doesn't have whole metadata.");
+  }
 }
 
 void HandshakeExtensionMessage::setPeer(const PeerHandle& peer)
@@ -122,11 +160,11 @@ HandshakeExtensionMessage::create(const unsigned char* data, size_t length)
   if(length < 1) {
     throw DL_ABORT_EX
       (StringFormat(MSG_TOO_SMALL_PAYLOAD_SIZE,
-		    EXTENSION_NAME.c_str(), length).str());
+                    EXTENSION_NAME.c_str(), length).str());
   }
   HandshakeExtensionMessageHandle msg(new HandshakeExtensionMessage());
   msg->_logger->debug("Creating HandshakeExtensionMessage from %s",
-		      util::urlencode(data, length).c_str());
+                      util::urlencode(data, length).c_str());
   const BDE dict = bencode::decode(data+1, length-1);
   if(!dict.isDict()) {
     throw DL_ABORT_EX("Unexpected payload format for extended message handshake");
@@ -142,12 +180,17 @@ HandshakeExtensionMessage::create(const unsigned char* data, size_t length)
   const BDE& extDict = dict["m"];
   if(extDict.isDict()) {
     for(BDE::Dict::const_iterator i = extDict.dictBegin();
-	i != extDict.dictEnd(); ++i) {
+        i != extDict.dictEnd(); ++i) {
       if((*i).second.isInteger()) {
-	msg->_extensions[(*i).first] = (*i).second.i();
+        msg->_extensions[(*i).first] = (*i).second.i();
       }
     }
   }
+  const BDE& metadataSize = dict["metadata_size"];
+  // Only accept metadata smaller than 1MiB
+  if(metadataSize.isInteger() && metadataSize.i() <= 1024*1024) {
+    msg->_metadataSize = metadataSize.i();
+  }
   return msg;
 }
 
