@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -77,19 +77,31 @@ public:
 
   SharedHandle<Range> getRange() const;
 
-  const std::string& getResponseStatus() const;
+  const std::string& getResponseStatus() const
+  {
+    return _responseStatus;
+  }
 
   void setResponseStatus(const std::string& responseStatus);
 
-  const std::string& getVersion() const;
+  const std::string& getVersion() const
+  {
+    return _version;
+  }
 
   void setVersion(const std::string& version);
 
-  const std::string& getMethod() const;
+  const std::string& getMethod() const
+  {
+    return _method;
+  }
 
   void setMethod(const std::string& method);
 
-  const std::string& getRequestPath() const;
+  const std::string& getRequestPath() const
+  {
+    return _requestPath;
+  }
 
   void setRequestPath(const std::string& requestPath);
 
@@ -128,6 +140,8 @@ public:
 
   static const std::string LAST_MODIFIED;
 
+  static const std::string ACCEPT_ENCODING;
+
   static const std::string HTTP_1_1;
 
   static const std::string S200;
