@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -33,7 +33,7 @@
  */
 /* copyright --> */
 #include "IndexBtMessage.h"
-#include "Util.h"
+#include "util.h"
 #include "a2functional.h"
 #include "bittorrent_helper.h"
 
@@ -62,7 +62,7 @@ size_t IndexBtMessage::getMessageLength()
 
 std::string IndexBtMessage::toString() const
 {
-  return strconcat(getName(), " index=", Util::itos(_index));
+  return strconcat(getName(), " index=", util::itos(_index));
 }
 
 } // namespace aria2
