@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,8 +35,9 @@
 #include "NsCookieParser.h"
 
 #include <fstream>
+#include <vector>
 
-#include "Util.h"
+#include "util.h"
 #include "A2STR.h"
 #include "DlAbortEx.h"
 #include "StringFormat.h"
@@ -51,24 +52,24 @@ static const std::string C_TRUE("TRUE");
 
 static Cookie parseNsCookie(const std::string& nsCookieStr)
 {
-  std::deque<std::string> vs;
-  Util::slice(vs, nsCookieStr, '\t', true);
+  std::vector<std::string> vs;
+  util::split(nsCookieStr, std::back_inserter(vs), "\t", true);
   if(vs.size() < 6 ) {
     return Cookie();
   }
 
-  int64_t expireDate = Util::parseLLInt(vs[4]);
+  int64_t expireDate = util::parseLLInt(vs[4]);
   // TODO assuming time_t is int32_t...
   if(expireDate > INT32_MAX) {
     expireDate = INT32_MAX;
   }
 
   Cookie c(vs[5], // name
-	   vs.size() >= 7? vs[6]:A2STR::NIL, // value
-	   expireDate, // expires
-	   vs[2], // path
-	   vs[0], // domain
-	   vs[3] == C_TRUE ? true : false);
+           vs.size() >= 7? vs[6]:A2STR::NIL, // value
+           expireDate, // expires
+           vs[2], // path
+           vs[0], // domain
+           vs[3] == C_TRUE ? true : false);
 
   return c;
 }
@@ -83,13 +84,13 @@ std::deque<Cookie> NsCookieParser::parse(const std::string& filename)
   std::string line;
   std::deque<Cookie> cookies;
   while(getline(s, line)) {
-    if(Util::startsWith(line, A2STR::SHARP_C)) {
+    if(util::startsWith(line, A2STR::SHARP_C)) {
       continue;
     }
     try {
       Cookie c = parseNsCookie(line);
       if(c.good()) {
-	cookies.push_back(c);
+        cookies.push_back(c);
       }
     } catch(RecoverableException& e) {
       // ignore malformed cookie entry
