@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -42,21 +42,19 @@
 
 namespace aria2 {
 
-class Option;
 class Logger;
 class SocketCore;
 class ARC4Encryptor;
 class ARC4Decryptor;
 
-// we assume maximum length of incoming message is "piece" message with 16KB
-// data. Messages beyond that size are dropped.
-#define MAX_PAYLOAD_LEN (9+16*1024)
+// The maximum length of payload. Messages beyond that length are
+// dropped.
+#define MAX_PAYLOAD_LEN (16*1024+128)
 
 class PeerConnection {
 private:
   int32_t cuid;
   SharedHandle<SocketCore> socket;
-  const Option* option;
   Logger* logger;
 
   unsigned char resbuf[MAX_PAYLOAD_LEN];
@@ -78,7 +76,7 @@ private:
   ssize_t sendData(const unsigned char* data, size_t length, bool encryption);
 
 public:
-  PeerConnection(int32_t cuid, const SharedHandle<SocketCore>& socket, const Option* op);
+  PeerConnection(int32_t cuid, const SharedHandle<SocketCore>& socket);
 
   ~PeerConnection();
   
@@ -96,7 +94,7 @@ public:
   bool receiveHandshake(unsigned char* data, size_t& dataLength, bool peek = false);
 
   void enableEncryption(const SharedHandle<ARC4Encryptor>& encryptor,
-			const SharedHandle<ARC4Decryptor>& decryptor);
+                        const SharedHandle<ARC4Decryptor>& decryptor);
 
   void presetBuffer(const unsigned char* data, size_t length);
 
