@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,7 +36,7 @@
 #define _D_RANGE_BT_MESSAGE_H_
 
 #include "SimpleBtMessage.h"
-#include "PeerMessageUtil.h"
+#include "bittorrent_helper.h"
 
 namespace aria2 {
 
@@ -53,17 +53,17 @@ protected:
   static SharedHandle<T> create
   (const unsigned char* data, size_t dataLength)
   {
-    PeerMessageUtil::assertPayloadLengthEqual(13, dataLength, T::NAME);
-    PeerMessageUtil::assertID(T::ID, data, T::NAME);
+    bittorrent::assertPayloadLengthEqual(13, dataLength, T::NAME);
+    bittorrent::assertID(T::ID, data, T::NAME);
     SharedHandle<T> message(new T());
-    message->setIndex(PeerMessageUtil::getIntParam(data, 1));
-    message->setBegin(PeerMessageUtil::getIntParam(data, 5));
-    message->setLength(PeerMessageUtil::getIntParam(data, 9));
+    message->setIndex(bittorrent::getIntParam(data, 1));
+    message->setBegin(bittorrent::getIntParam(data, 5));
+    message->setLength(bittorrent::getIntParam(data, 9));
     return message;
   }
 public:
   RangeBtMessage(uint8_t id, const std::string& name,
-		 size_t index, uint32_t begin, size_t length);
+                 size_t index, uint32_t begin, size_t length);
 
   virtual ~RangeBtMessage();
 
