@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,46 +38,33 @@
 
 #include "DownloadEngine.h"
 #include "Option.h"
-#include "Request.h"
 #include "prefs.h"
 #include "RequestGroup.h"
-#include "InitiateConnectionCommandFactory.h"
 #include "DownloadContext.h"
 #include "Command.h"
 
 namespace aria2 {
 
-StreamFileAllocationEntry::StreamFileAllocationEntry(const RequestHandle& currentRequest,
-						     RequestGroup* requestGroup,
-						     Command* nextCommand):
-  FileAllocationEntry(requestGroup, nextCommand),
-  _currentRequest(currentRequest)
+StreamFileAllocationEntry::StreamFileAllocationEntry(RequestGroup* requestGroup,
+                                                     Command* nextCommand):
+  FileAllocationEntry(requestGroup, nextCommand)
 {}
 
 StreamFileAllocationEntry::~StreamFileAllocationEntry() {}
 
 void StreamFileAllocationEntry::prepareForNextAction(std::deque<Command*>& commands,
-						     DownloadEngine* e)
+                                                     DownloadEngine* e)
 {
   _requestGroup->getDownloadContext()->resetDownloadStartTime();
   if(_nextCommand) {
     // give _nextCommand a chance to execute in the next execution loop.
     _nextCommand->setStatus(Command::STATUS_ONESHOT_REALTIME);
+    e->setNoWait(true);
     commands.push_back(popNextCommand());
     // try remaining uris
     _requestGroup->createNextCommandWithAdj(commands, e, -1);
   } else {
-    if(_currentRequest.isNull()) {
-      _requestGroup->createNextCommandWithAdj(commands, e, 0);
-    } else {
-      Command* command =
-	InitiateConnectionCommandFactory::createInitiateConnectionCommand
-	(e->newCUID(), _currentRequest, _requestGroup, e);
-
-      commands.push_back(command);
-
-      _requestGroup->createNextCommandWithAdj(commands, e, -1);
-    }
+    _requestGroup->createNextCommandWithAdj(commands, e, 0);
   }
 }
 
