@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,7 +36,7 @@
 #include "XmlRpcRequestParserStateMachine.h"
 #include "XmlRpcElements.h"
 #include "RecoverableException.h"
-#include "Util.h"
+#include "util.h"
 #include "Base64.h"
 
 namespace aria2 {
@@ -82,7 +82,7 @@ void MethodCallXmlRpcRequestParserState::beginElement
 {
   if(name == elements::METHOD_NAME) {
     stm->pushMethodNameState();
-  } else if(name == elements::PARAMS) {
+  } else if(name == elements::A2_PARAMS) {
     stm->setCurrentFrameValue(BDE::list());
     stm->pushParamsState();
   } else {
@@ -185,7 +185,7 @@ void IntXmlRpcRequestParserState::endElement
  const std::string& characters)
 {
   try {
-    int64_t value = Util::parseLLInt(characters);
+    int64_t value = util::parseLLInt(characters);
     stm->setCurrentFrameValue(BDE(value));
   } catch(RecoverableException& e) {
     // nothing to do here: We just leave current frame value to BDE::none
