@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -41,7 +41,7 @@
 #include "DownloadContext.h"
 #include "Randomizer.h"
 #include "bencode.h"
-#include "Util.h"
+#include "util.h"
 #include "DlAbortEx.h"
 #include "message.h"
 #include "StringFormat.h"
@@ -52,7 +52,8 @@
 #include "a2netcompat.h"
 #include "BtConstants.h"
 #include "bitfield.h"
-#include "DHTUtil.h"
+#include "base32.h"
+#include "magnet.h"
 
 namespace aria2 {
 
@@ -126,16 +127,20 @@ const std::string MULTI("multi");
 
 const std::string SINGLE("single");
 
+const std::string METADATA_SIZE("metadataSize");
+
+const std::string METADATA("metadata");
+
 static void extractPieceHash(const SharedHandle<DownloadContext>& ctx,
-			     const std::string& hashData,
-			     size_t hashLength,
-			     size_t numPieces)
+                             const std::string& hashData,
+                             size_t hashLength,
+                             size_t numPieces)
 {
   std::vector<std::string> pieceHashes;
   pieceHashes.reserve(numPieces);
   for(size_t i = 0; i < numPieces; ++i) {
-    pieceHashes.push_back(Util::toHex(hashData.data()+i*hashLength,
-				      hashLength));
+    pieceHashes.push_back(util::toHex(hashData.data()+i*hashLength,
+                                      hashLength));
   }
   ctx->setPieceHashes(pieceHashes.begin(), pieceHashes.end());
   ctx->setPieceHashAlgo(MessageDigestContext::SHA1);
@@ -146,9 +151,9 @@ static void extractUrlList
 {
   if(bde.isList()) {
     for(BDE::List::const_iterator itr = bde.listBegin();
-	itr != bde.listEnd(); ++itr) {
+        itr != bde.listEnd(); ++itr) {
       if((*itr).isString()) {
-	uris.push_back((*itr).s());
+        uris.push_back((*itr).s());
       }
     }
     torrent[URL_LIST] = bde;
@@ -168,7 +173,7 @@ static OutputIterator createUri
  const std::string& filePath)
 {
   for(; first != last; ++first) {
-    if(Util::endsWith(*first, "/")) {
+    if(util::endsWith(*first, "/")) {
       *out++ = (*first)+filePath;
     } else {
       *out++ = (*first)+"/"+filePath;
@@ -195,10 +200,10 @@ static void extractFileEntries
     }
     const BDE& nameData = infoDict[nameKey];
     if(nameData.isString()) {
-      // Slice path by '/' just in case nasty ".." is included in name
-      std::deque<std::string> pathelems;
-      Util::slice(pathelems, nameData.s(), '/');
-      name = Util::joinPath(pathelems.begin(), pathelems.end());
+      // Split path by '/' just in case nasty ".." is included in name
+      std::vector<std::string> pathelems;
+      util::split(nameData.s(), std::back_inserter(pathelems), "/");
+      name = util::joinPath(pathelems.begin(), pathelems.end());
       torrent[NAME] = nameData.s();
     } else {
       name = strconcat(File(defaultName).getBasename(), ".file");
@@ -218,46 +223,46 @@ static void extractFileEntries
     // multi-file mode
     torrent[MODE] = MULTI;
     for(BDE::List::const_iterator itr = filesList.listBegin();
-	itr != filesList.listEnd(); ++itr) {
+        itr != filesList.listEnd(); ++itr) {
       const BDE& fileDict = *itr;
       if(!fileDict.isDict()) {
-	continue;
+        continue;
       }
       const BDE& fileLengthData = fileDict[C_LENGTH];
       if(!fileLengthData.isInteger()) {
-	throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-				       C_LENGTH.c_str()).str());
+        throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
+                                       C_LENGTH.c_str()).str());
       }
       length += fileLengthData.i();
 
       std::string pathKey;
       if(fileDict.containsKey(C_PATH_UTF8)) {
-	pathKey = C_PATH_UTF8;
+        pathKey = C_PATH_UTF8;
       } else {
-	pathKey = C_PATH;
+        pathKey = C_PATH;
       }
       const BDE& pathList = fileDict[pathKey];
       if(!pathList.isList() || pathList.empty()) {
-	throw DL_ABORT_EX("Path is empty.");
+        throw DL_ABORT_EX("Path is empty.");
       }
       
       std::vector<std::string> pathelem(pathList.size());
       std::transform(pathList.listBegin(), pathList.listEnd(), pathelem.begin(),
-		     std::mem_fun_ref(&BDE::s));
+                     std::mem_fun_ref(&BDE::s));
       std::string path = name;
-      strappend(path, "/", Util::joinPath(pathelem.begin(), pathelem.end()));
+      strappend(path, "/", util::joinPath(pathelem.begin(), pathelem.end()));
       // Split path with '/' again because each pathList element can
       // contain "/" inside.
-      std::deque<std::string> elements;
-      Util::slice(elements, path, '/');
-      path = Util::joinPath(elements.begin(), elements.end());
+      std::vector<std::string> elements;
+      util::split(path, std::back_inserter(elements), "/");
+      path = util::joinPath(elements.begin(), elements.end());
 
       std::deque<std::string> uris;
       createUri(urlList.begin(), urlList.end(), std::back_inserter(uris), path);
       SharedHandle<FileEntry> fileEntry
-	(new FileEntry(strconcat(ctx->getDir(), "/", path),
-		       fileLengthData.i(),
-		       offset, uris));
+        (new FileEntry(util::applyDir(ctx->getDir(), path),
+                       fileLengthData.i(),
+                       offset, uris));
       fileEntries.push_back(fileEntry);
       offset += fileEntry->getLength();
     }
@@ -266,8 +271,8 @@ static void extractFileEntries
     torrent[MODE] = SINGLE;
     const BDE& lengthData = infoDict[C_LENGTH];
     if(!lengthData.isInteger()) {
-	throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-				       C_LENGTH.c_str()).str());      
+      throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
+                                     C_LENGTH.c_str()).str());      
     }
     uint64_t totalLength = lengthData.i();
 
@@ -275,22 +280,22 @@ static void extractFileEntries
     // concatenate name to it. Specification just says so.
     std::deque<std::string> uris;
     for(std::vector<std::string>::const_iterator i = urlList.begin();
-	i != urlList.end(); ++i) {
-      if(Util::endsWith(*i, "/")) {
-	uris.push_back((*i)+name);
+        i != urlList.end(); ++i) {
+      if(util::endsWith(*i, "/")) {
+        uris.push_back((*i)+name);
       } else {
-	uris.push_back(*i);
+        uris.push_back(*i);
       }
     }
 
     SharedHandle<FileEntry> fileEntry
-      (new FileEntry(strconcat(ctx->getDir(), "/", name),totalLength, 0,
-		     uris));
+      (new FileEntry(util::applyDir(ctx->getDir(), name),totalLength, 0,
+                     uris));
     fileEntries.push_back(fileEntry);
   }
   ctx->setFileEntries(fileEntries.begin(), fileEntries.end());
   if(torrent[MODE].s() == MULTI) {
-    ctx->setBasePath(strconcat(ctx->getDir(), "/", name));
+    ctx->setBasePath(util::applyDir(ctx->getDir(), name));
   }
 }
 
@@ -299,12 +304,22 @@ static void extractAnnounce(BDE& torrent, const BDE& rootDict)
   const BDE& announceList = rootDict[C_ANNOUNCE_LIST];
   if(announceList.isList()) {
     torrent[ANNOUNCE_LIST] = announceList;
+    BDE& tiers = torrent[ANNOUNCE_LIST];
+    for(BDE::List::iterator tieriter = tiers.listBegin();
+        tieriter != tiers.listEnd(); ++tieriter) {
+      for(BDE::List::iterator uriiter = (*tieriter).listBegin();
+          uriiter != (*tieriter).listEnd(); ++uriiter) {
+        if((*uriiter).isString()) {
+          *uriiter = util::trim((*uriiter).s());
+        }
+      }
+    }
   } else {
     const BDE& announce = rootDict[C_ANNOUNCE];
     BDE announceList = BDE::list();
     if(announce.isString()) {
       announceList << BDE::list();
-      announceList[0] << announce;
+      announceList[0] << util::trim(announce.s());
     }
     torrent[ANNOUNCE_LIST] = announceList;
   }
@@ -315,21 +330,21 @@ static void extractNodes(BDE& torrent, const BDE& nodesList)
   BDE nodes = BDE::list();
   if(nodesList.isList()) {
     for(BDE::List::const_iterator i = nodesList.listBegin();
-	i != nodesList.listEnd(); ++i) {
+        i != nodesList.listEnd(); ++i) {
       const BDE& addrPairList = (*i);
       if(!addrPairList.isList() || addrPairList.size() != 2) {
-	continue;
+        continue;
       }
       const BDE& hostname = addrPairList[0];
       if(!hostname.isString()) {
-	continue;
+        continue;
       }
-      if(Util::trim(hostname.s()).empty()) {
-	continue;
+      if(util::trim(hostname.s()).empty()) {
+        continue;
       }
       const BDE& port = addrPairList[1];
       if(!port.isInteger() || !(0 < port.i() && port.i() < 65536)) {
-	continue;
+        continue;
       }
       BDE node = BDE::dict();
       node[HOSTNAME] = hostname;
@@ -353,7 +368,7 @@ static void processRootDictionary
   const BDE& infoDict = rootDict[C_INFO];
   if(!infoDict.isDict()) {
     throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-				   C_INFO.c_str()).str());
+                                   C_INFO.c_str()).str());
   }
   BDE torrent = BDE::dict();
 
@@ -361,16 +376,18 @@ static void processRootDictionary
   std::string encodedInfoDict = bencode::encode(infoDict);
   unsigned char infoHash[INFO_HASH_LENGTH];
   MessageDigestHelper::digest(infoHash, INFO_HASH_LENGTH,
-			      MessageDigestContext::SHA1,
-			      encodedInfoDict.data(),
-			      encodedInfoDict.size());
+                              MessageDigestContext::SHA1,
+                              encodedInfoDict.data(),
+                              encodedInfoDict.size());
   torrent[INFO_HASH] = std::string(&infoHash[0], &infoHash[INFO_HASH_LENGTH]);
+  torrent[METADATA] = encodedInfoDict;
+  torrent[METADATA_SIZE] = encodedInfoDict.size();
 
   // calculate the number of pieces
   const BDE& piecesData = infoDict[C_PIECES];
   if(!piecesData.isString()) {
     throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-				   C_PIECES.c_str()).str());
+                                   C_PIECES.c_str()).str());
   }
   // Commented out To download 0 length torrent.
   //   if(piecesData.s().empty()) {
@@ -385,7 +402,7 @@ static void processRootDictionary
   const BDE& pieceLengthData = infoDict[C_PIECE_LENGTH];
   if(!pieceLengthData.isInteger()) {
     throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-				   C_PIECE_LENGTH.c_str()).str());
+                                   C_PIECE_LENGTH.c_str()).str());
   }
   size_t pieceLength = pieceLengthData.i();
   ctx->setPieceLength(pieceLength);
@@ -441,78 +458,76 @@ static void processRootDictionary
 }
 
 void load(const std::string& torrentFile,
-	  const SharedHandle<DownloadContext>& ctx,
-	  const std::string& overrideName)
+          const SharedHandle<DownloadContext>& ctx,
+          const std::string& overrideName)
 {
   processRootDictionary(ctx,
-			bencode::decodeFromFile(torrentFile),
-			torrentFile,
-			overrideName,
-			std::deque<std::string>());
+                        bencode::decodeFromFile(torrentFile),
+                        torrentFile,
+                        overrideName,
+                        std::deque<std::string>());
 }
 
 void load(const std::string& torrentFile,
-	  const SharedHandle<DownloadContext>& ctx,
-	  const std::deque<std::string>& uris,
-	  const std::string& overrideName)
+          const SharedHandle<DownloadContext>& ctx,
+          const std::deque<std::string>& uris,
+          const std::string& overrideName)
 {
   processRootDictionary(ctx,
-			bencode::decodeFromFile(torrentFile),
-			torrentFile,
-			overrideName,
-			uris);
+                        bencode::decodeFromFile(torrentFile),
+                        torrentFile,
+                        overrideName,
+                        uris);
 }
 
 void loadFromMemory(const unsigned char* content,
-		    size_t length,
-		    const SharedHandle<DownloadContext>& ctx,
-		    const std::string& defaultName,
-		    const std::string& overrideName)
+                    size_t length,
+                    const SharedHandle<DownloadContext>& ctx,
+                    const std::string& defaultName,
+                    const std::string& overrideName)
 {
   processRootDictionary(ctx,
-			bencode::decode(content, length),
-			defaultName,
-			overrideName,
-			std::deque<std::string>());
+                        bencode::decode(content, length),
+                        defaultName,
+                        overrideName,
+                        std::deque<std::string>());
 }
 
 void loadFromMemory(const unsigned char* content,
-		    size_t length,
-		    const SharedHandle<DownloadContext>& ctx,
-		    const std::deque<std::string>& uris,
-		    const std::string& defaultName,
-		    const std::string& overrideName)
+                    size_t length,
+                    const SharedHandle<DownloadContext>& ctx,
+                    const std::deque<std::string>& uris,
+                    const std::string& defaultName,
+                    const std::string& overrideName)
 {
   processRootDictionary(ctx,
-			bencode::decode(content, length),
-			defaultName,
-			overrideName,
-			uris);
+                        bencode::decode(content, length),
+                        defaultName,
+                        overrideName,
+                        uris);
 }
 
 void loadFromMemory(const std::string& context,
-		    const SharedHandle<DownloadContext>& ctx,
-		    const std::string& defaultName,
-		    const std::string& overrideName)
+                    const SharedHandle<DownloadContext>& ctx,
+                    const std::string& defaultName,
+                    const std::string& overrideName)
 {
   processRootDictionary
     (ctx,
-     bencode::decode(reinterpret_cast<const unsigned char*>(context.c_str()),
-		     context.size()),
+     bencode::decode(context),
      defaultName, overrideName,
      std::deque<std::string>());
 }
 
 void loadFromMemory(const std::string& context,
-		    const SharedHandle<DownloadContext>& ctx,
-		    const std::deque<std::string>& uris,
-		    const std::string& defaultName,
-		    const std::string& overrideName)
+                    const SharedHandle<DownloadContext>& ctx,
+                    const std::deque<std::string>& uris,
+                    const std::string& defaultName,
+                    const std::string& overrideName)
 {
   processRootDictionary
     (ctx,
-     bencode::decode(reinterpret_cast<const unsigned char*>(context.c_str()),
-		     context.size()),
+     bencode::decode(context),
      defaultName, overrideName,
      uris);
 }
@@ -526,7 +541,7 @@ getInfoHash(const SharedHandle<DownloadContext>& downloadContext)
 std::string
 getInfoHashString(const SharedHandle<DownloadContext>& downloadContext)
 {
-  return Util::toHex(downloadContext->getAttribute(BITTORRENT)[INFO_HASH].s());
+  return util::toHex(downloadContext->getAttribute(BITTORRENT)[INFO_HASH].s());
 }
 
 void print(std::ostream& o, const SharedHandle<DownloadContext>& dctx)
@@ -558,26 +573,27 @@ void print(std::ostream& o, const SharedHandle<DownloadContext>& dctx)
       continue;
     }
     for(BDE::List::const_iterator i = (*tieritr).listBegin();
-	i != (*tieritr).listEnd(); ++i) {
+        i != (*tieritr).listEnd(); ++i) {
       o << " " << (*i).s();
     }
     o << "\n";
   }
-  o << "Info Hash: " << Util::toHex(torrentAttrs[INFO_HASH].s()) << "\n";
-  o << "Piece Length: " << Util::abbrevSize(dctx->getPieceLength()) << "B\n";
+  o << "Info Hash: " << util::toHex(torrentAttrs[INFO_HASH].s()) << "\n";
+  o << "Piece Length: " << util::abbrevSize(dctx->getPieceLength()) << "B\n";
   o << "The Number of Pieces: " << dctx->getNumPieces() << "\n";
-  o << "Total Length: " << Util::abbrevSize(dctx->getTotalLength()) << "B ("
-    << Util::uitos(dctx->getTotalLength(), true) << ")\n";
+  o << "Total Length: " << util::abbrevSize(dctx->getTotalLength()) << "B ("
+    << util::uitos(dctx->getTotalLength(), true) << ")\n";
   if(!torrentAttrs[URL_LIST].empty()) {
     const BDE& urlList = torrentAttrs[URL_LIST];
     o << "URL List: " << "\n";
     for(BDE::List::const_iterator i = urlList.listBegin();
-	i != urlList.listEnd(); ++i) {
+        i != urlList.listEnd(); ++i) {
       o << " " << (*i).s() << "\n";
     }
   }
   o << "Name: " << torrentAttrs[NAME].s() << "\n";
-  Util::toStream(dctx->getFileEntries().begin(), dctx->getFileEntries().end(), o);
+  o << "Magnet URI: " << torrent2Magnet(torrentAttrs) << "\n";
+  util::toStream(dctx->getFileEntries().begin(), dctx->getFileEntries().end(), o);
 }
 
 void computeFastSet
@@ -610,7 +626,7 @@ void computeFastSet
       uint32_t y = ntohl(ny);
       size_t index = y%numPieces;
       if(std::find(fastSet.begin(), fastSet.end(), index) == fastSet.end()) {
-	fastSet.push_back(index);
+        fastSet.push_back(index);
       }
     }
     unsigned char temp[20];
@@ -625,8 +641,7 @@ std::string generatePeerId(const std::string& peerIdPrefix)
   unsigned char buf[20];
   int len = 20-peerIdPrefix.size();
   if(len > 0) {
-    DHTUtil::generateRandomData(buf, len);
-
+    util::generateRandomData(buf, len);
     peerId += std::string(&buf[0], &buf[len]);
   } if(peerId.size() > 20) {
     peerId.erase(20);
@@ -685,7 +700,7 @@ void checkIndex(size_t index, size_t pieces)
 {
   if(!(index < pieces)) {
     throw DL_ABORT_EX(StringFormat("Invalid index: %lu",
-				 static_cast<unsigned long>(index)).str());
+                                   static_cast<unsigned long>(index)).str());
   }
 }
 
@@ -701,13 +716,13 @@ void checkLength(size_t length)
   if(length > MAX_BLOCK_LENGTH) {
     throw DL_ABORT_EX
       (StringFormat("Length too long: %lu > %uKB",
-		    static_cast<unsigned long>(length),
-		    MAX_BLOCK_LENGTH/1024).str());
+                    static_cast<unsigned long>(length),
+                    MAX_BLOCK_LENGTH/1024).str());
   }
   if(length == 0) {
     throw DL_ABORT_EX
       (StringFormat("Invalid length: %lu",
-		    static_cast<unsigned long>(length)).str());
+                    static_cast<unsigned long>(length)).str());
   }
 }
 
@@ -716,15 +731,15 @@ void checkRange(uint32_t begin, size_t length, size_t pieceLength)
   if(!(0 < length)) {
     throw DL_ABORT_EX
       (StringFormat("Invalid range: begin=%u, length=%lu",
-		    begin,
-		    static_cast<unsigned long>(length)).str());
+                    begin,
+                    static_cast<unsigned long>(length)).str());
   }
   uint32_t end = begin+length;
   if(!(end <= pieceLength)) {
     throw DL_ABORT_EX
       (StringFormat("Invalid range: begin=%u, length=%lu",
-		    begin,
-		    static_cast<unsigned long>(length)).str());
+                    begin,
+                    static_cast<unsigned long>(length)).str());
   }
 }
 
@@ -734,11 +749,11 @@ void checkBitfield
   if(!(bitfieldLength == (pieces+7)/8)) {
     throw DL_ABORT_EX
       (StringFormat("Invalid bitfield length: %lu",
-		    static_cast<unsigned long>(bitfieldLength)).str());
+                    static_cast<unsigned long>(bitfieldLength)).str());
   }
   // Check if last byte contains garbage set bit.
   if(bitfield[bitfieldLength-1]&~bitfield::lastByteMask(pieces)) {
-      throw DL_ABORT_EX("Invalid bitfield");
+    throw DL_ABORT_EX("Invalid bitfield");
   }
 }
 
@@ -775,10 +790,9 @@ bool createcompact
     return false;
   }
   struct sockaddr_in* in = reinterpret_cast<struct sockaddr_in*>(res->ai_addr);
-  uint32_t* addrp = (uint32_t*)compact;
-  *addrp = in->sin_addr.s_addr;
-  uint16_t* portp = (uint16_t*)(compact+4);
-  *portp = htons(port);
+  memcpy(compact, &(in->sin_addr.s_addr), sizeof(uint32_t));
+  uint16_t port_nworder(htons(port));
+  memcpy(compact+4, &port_nworder, sizeof(uint16_t));
   freeaddrinfo(res);
   return true;
 }
@@ -792,17 +806,19 @@ std::pair<std::string, uint16_t> unpackcompact(const unsigned char* compact)
   in.sin_len = sizeof(in);
 #endif // HAVE_SOCKADDR_IN_SIN_LEN
   in.sin_family = AF_INET;
-  in.sin_addr.s_addr = *reinterpret_cast<const uint32_t*>(compact);
+  memcpy(&(in.sin_addr.s_addr), compact, sizeof(uint32_t));
   in.sin_port = 0;
   char host[NI_MAXHOST];
   int s;
   s = getnameinfo(reinterpret_cast<const struct sockaddr*>(&in), sizeof(in),
-		  host, NI_MAXHOST, 0, NI_MAXSERV,
-		  NI_NUMERICHOST);
+                  host, NI_MAXHOST, 0, NI_MAXSERV,
+                  NI_NUMERICHOST);
   if(s) {
     return std::pair<std::string, uint16_t>();
   }
-  uint16_t port = ntohs(*(uint16_t*)(compact+sizeof(uint32_t)));
+  uint16_t port_nworder;
+  memcpy(&port_nworder, compact+sizeof(uint32_t), sizeof(uint16_t));
+  uint16_t port = ntohs(port_nworder);
   return std::pair<std::string, uint16_t>(host, port);
 }
 
@@ -822,7 +838,7 @@ void assertPayloadLengthEqual
   if(expected != actual) {
     throw DL_ABORT_EX
       (StringFormat(EX_INVALID_PAYLOAD_SIZE, msgName.c_str(),
-		    actual, expected).str());
+                    actual, expected).str());
   }
 }
 
@@ -833,10 +849,113 @@ void assertID
   if(expected != id) {
     throw DL_ABORT_EX
       (StringFormat(EX_INVALID_BT_MESSAGE_ID, id, msgName.c_str(),
-		    expected).str());
+                    expected).str());
   }
 }
 
+BDE parseMagnet(const std::string& magnet)
+{
+  BDE result;
+  BDE r = magnet::parse(magnet);
+  if(r.isNone()) {
+    throw DL_ABORT_EX("Bad BitTorrent Magnet URI.");
+  }
+  if(!r.containsKey("xt")) {
+    throw DL_ABORT_EX("Missing xt parameter in Magnet URI.");
+  }
+  const BDE& xts = r["xt"];
+  if(xts.size() == 0 || !util::startsWith(xts[0].s(), "urn:btih:")) {
+    throw DL_ABORT_EX("Bad BitTorrent Magnet URI.");
+  }
+  std::string infoHash = xts[0].s().substr(9);
+  if(infoHash.size() == 32) {
+    std::string rawhash = base32::decode(infoHash);
+    if(rawhash.size() != 20) {
+      throw DL_ABORT_EX("Invalid BitTorrent Info Hash.");
+    }
+    infoHash = rawhash;
+  } else if(infoHash.size() == 40) {
+    std::string rawhash = util::fromHex(infoHash);
+    if(rawhash.empty()) {
+      throw DL_ABORT_EX("Invalid BitTorrent Info Hash.");
+    }
+    infoHash = rawhash;
+  } else {
+    throw DL_ABORT_EX("Invalid BitTorrent Info Hash.");
+  }
+  BDE announceList = BDE::list();
+  if(r.containsKey("tr")) {
+    const BDE& uris = r["tr"];
+    for(BDE::List::const_iterator i = uris.listBegin(); i != uris.listEnd();
+        ++i) {
+      BDE tier = BDE::list();
+      tier << *i;
+      announceList << tier;
+    }
+  }
+  std::string name = "[METADATA]";
+  if(r.containsKey("dn") && r["dn"].size()) {
+    name += r["dn"][0].s();
+  } else {
+    name += util::toHex(infoHash);
+  }
+  BDE attrs = BDE::dict();
+  attrs[INFO_HASH] = infoHash;
+  attrs[NAME] = name;
+  attrs[ANNOUNCE_LIST] = announceList;
+  result = attrs;
+  return result;
+}
+
+void loadMagnet
+(const std::string& magnet, const SharedHandle<DownloadContext>& dctx)
+{
+  BDE attrs = parseMagnet(magnet);
+  dctx->setAttribute(BITTORRENT, attrs);
+}
+
+std::string metadata2Torrent(const std::string& metadata, const BDE& attrs)
+{
+  std::string torrent = "d";
+  if(attrs.containsKey(bittorrent::ANNOUNCE_LIST)) {
+    const BDE& announceList = attrs[bittorrent::ANNOUNCE_LIST];
+    if(announceList.size() > 0) {
+      torrent += "13:announce-list";
+      torrent += bencode::encode(announceList);
+    }
+  }
+  torrent +=
+    strconcat("4:info", metadata, "e");
+  return torrent;
+}
+
+std::string torrent2Magnet(const BDE& attrs)
+{
+  std::string uri = "magnet:?";
+  if(attrs.containsKey(INFO_HASH)) {
+    uri += "xt=urn:btih:";
+    uri += util::toUpper(util::toHex(attrs[INFO_HASH].s()));
+  } else {
+    return A2STR::NIL;
+  }
+  if(attrs.containsKey(NAME)) {
+    uri += "&dn=";
+    uri += util::urlencode(attrs[NAME].s());
+  }
+  if(attrs.containsKey(ANNOUNCE_LIST)) {
+    const BDE& tiers = attrs[ANNOUNCE_LIST];
+    for(BDE::List::const_iterator tieriter = tiers.listBegin();
+        tieriter != tiers.listEnd(); ++tieriter) {
+      for(BDE::List::const_iterator uriiter = (*tieriter).listBegin();
+          uriiter != (*tieriter).listEnd(); ++uriiter) {
+        uri += "&tr=";
+        uri += util::urlencode((*uriiter).s());
+      }
+    }
+  }
+  return uri;
+}
+
 } // namespace bittorrent
 
 } // namespace aria2
